==> adeptutils-9.0.0%2B1.tar.gz: lib/src/connection_utils.dart <==
import 'package:http/http.dart' as http;
import 'dart:io';
import 'dart:async';

enum CheckMethod {
  OPTIONS,
  HEAD,
}

class ConnectionUtils {
  static Future<http.Response> options(String url) async {
    final client = http.Client();
    final request = http.Request('OPTIONS', Uri.parse(url));
    final streamedResponse = await client.send(request);
    return http.Response.fromStream(streamedResponse);
  }

  static Future<http.Response> head(String url) => http.head(Uri.parse(url));

  static Future<bool> isResponseSuccessful(String url,
      {Duration? timeout,
      int? timeoutMillis,
      CheckMethod checkMethod = CheckMethod.OPTIONS}) async {
    final future =
        checkMethod == CheckMethod.OPTIONS ? options(url) : head(url);
    if (timeoutMillis != null) timeout = Duration(milliseconds: timeoutMillis);
    final response = await (timeout == null
        ? future
        : future.timeout(timeout,
            onTimeout: () => http.Response('', HttpStatus.requestTimeout)));
    return response.statusCode >= 200 || response.statusCode < 300;
  }

  static Future<bool> isResponseOnline(String url,
      {Duration? timeout,
      int? timeoutMillis,
      CheckMethod checkMethod = CheckMethod.OPTIONS}) async {
    final future =
        checkMethod == CheckMethod.OPTIONS ? options(url) : head(url);
    if (timeoutMillis != null) timeout = Duration(milliseconds: timeoutMillis);
    final response = await (timeout == null
        ? future
        : future.timeout(timeout,
            onTimeout: () => http.Response('', HttpStatus.requestTimeout)));
    switch (response.statusCode) {
      case HttpStatus.notFound:
      case HttpStatus.requestTimeout:
      case HttpStatus.gatewayTimeout:
      case HttpStatus.networkConnectTimeoutError:
        return false;
    }
    return true;
  }
}

==> adeptutils-9.2.2%2B1.tar.gz: lib/src/connection_utils.dart <==
import 'package:http/http.dart' as http;
import 'dart:io';
import 'dart:async';

enum CheckMethod {
  OPTIONS,
  HEAD,
}

class ConnectionUtils {
  static Future<http.Response> options(String url) async {
    final client = http.Client();
    final request = http.Request('OPTIONS', Uri.parse(url));
    final streamedResponse = await client.send(request);
    return http.Response.fromStream(streamedResponse);
  }

  static Future<http.Response> head(String url) => http.head(Uri.parse(url));

  static Future<bool> isResponseSuccessful(String url,
      {Duration? timeout,
      int? timeoutMillis,
      CheckMethod checkMethod = CheckMethod.OPTIONS}) async {
    final future =
        checkMethod == CheckMethod.OPTIONS ? options(url) : head(url);
    if (timeoutMillis != null) timeout = Duration(milliseconds: timeoutMillis);
    final response = await (timeout == null
        ? future
        : future.timeout(timeout,
            onTimeout: () => http.Response('', HttpStatus.requestTimeout)));
    return response.statusCode >= 200 && response.statusCode < 300;
  }

  static Future<bool> isResponseOnline(String url,
      {Duration? timeout,
      int? timeoutMillis,
      CheckMethod checkMethod = CheckMethod.OPTIONS}) async {
    final future =
        checkMethod == CheckMethod.OPTIONS ? options(url) : head(url);
    if (timeoutMillis != null) timeout = Duration(milliseconds: timeoutMillis);
    final response = await (timeout == null
        ? future
        : future.timeout(timeout,
            onTimeout: () => http.Response('', HttpStatus.requestTimeout)));
    switch (response.statusCode) {
      case HttpStatus.notFound:
      case HttpStatus.requestTimeout:
      case HttpStatus.gatewayTimeout:
      case HttpStatus.networkConnectTimeoutError:
        return false;
    }
    return true;
  }
}
